==> ejc-businessplan-impl-3.0.0-20220706.171536-96-sources.jar: com/ejianc/business/busniessplan/bean/FundrecoveryplanningdetailEntity.java <==
package com.ejianc.business.busniessplan.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 项目资金回收流程策划子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_businessplan_fundrecoveryplanningdetail")
public class FundrecoveryplanningdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="process")
    private java.lang.String process; // 流程
    @TableField(value="contract_start_end_time")
    private java.util.Date contractStartEndTime; // 合同约定申付起止时间
    @TableField(value="plan_start_end_time")
    private java.util.Date planStartEndTime; // 策划申付起止时间
    @TableField(value="reviewers")
    private java.lang.String reviewers; // 审核人员
    @TableField(value="docking")
    private java.lang.String docking; // 项目部跟踪、对接责任人员
    @TableField(value="response")
    private java.lang.String response; // 应对措施
    @TableField(value="payment_start_end_time")
    private java.lang.String paymentStartEndTime; // 合同约定申付起止时间
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }

    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 流程
     */
    public java.lang.String getProcess() {
        return process;
    }

    /**
     * 流程
     */
    public void setProcess(java.lang.String process) {
        this.process = process;
    }
    /**
     * 合同约定申付起止时间
     */
    public java.util.Date getContractStartEndTime() {
        return contractStartEndTime;
    }

    /**
     * 合同约定申付起止时间
     */
    public void setContractStartEndTime(java.util.Date contractStartEndTime) {
        this.contractStartEndTime = contractStartEndTime;
    }

    public String getPaymentStartEndTime() {
        return paymentStartEndTime;
    }

    public void setPaymentStartEndTime(String paymentStartEndTime) {
        this.paymentStartEndTime = paymentStartEndTime;
    }

    /**
     * 策划申付起止时间
     */
    public java.util.Date getPlanStartEndTime() {
        return planStartEndTime;
    }

    /**
     * 策划申付起止时间
     */
    public void setPlanStartEndTime(java.util.Date planStartEndTime) {
        this.planStartEndTime = planStartEndTime;
    }
    /**
     * 审核人员
     */
    public java.lang.String getReviewers() {
        return reviewers;
    }

    /**
     * 审核人员
     */
    public void setReviewers(java.lang.String reviewers) {
        this.reviewers = reviewers;
    }
    /**
     * 项目部跟踪、对接责任人员
     */
    public java.lang.String getDocking() {
        return docking;
    }

    /**
     * 项目部跟踪、对接责任人员
     */
    public void setDocking(java.lang.String docking) {
        this.docking = docking;
    }
    /**
     * 应对措施
     */
    public java.lang.String getResponse() {
        return response;
    }

    /**
     * 应对措施
     */
    public void setResponse(java.lang.String response) {
        this.response = response;
    }
    
}

==> ejc-businessplan-impl-3.0.0-20230321.070644-132-sources.jar: com/ejianc/business/busniessplan/bean/FundrecoveryplanningdetailEntity.java <==
package com.ejianc.business.busniessplan.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 项目资金回收流程策划子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_businessplan_fundrecoveryplanningdetail")
public class FundrecoveryplanningdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注
    @TableField(value="process")
    private java.lang.String process; // 流程
    @TableField(value="contract_start_end_time")
    private java.util.Date contractStartEndTime; // 合同约定申付起止时间
    @TableField(value="plan_start_end_time")
    private java.util.Date planStartEndTime; // 策划申付起止时间
    @TableField(value="reviewers")
    private java.lang.String reviewers; // 审核人员
    @TableField(value="docking")
    private java.lang.String docking; // 项目部跟踪、对接责任人员
    @TableField(value="response")
    private java.lang.String response; // 应对措施
    @TableField(value="payment_start_end_time")
    private java.lang.String paymentStartEndTime; // 合同约定申付起止时间

    @TableField(value="pay_start_end_time")
    private java.lang.String payStartEndTime; // 策划申付起止时间

    public String getPayStartEndTime() {
        return payStartEndTime;
    }

    public void setPayStartEndTime(String payStartEndTime) {
        this.payStartEndTime = payStartEndTime;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }

    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    /**
     * 流程
     */
    public java.lang.String getProcess() {
        return process;
    }

    /**
     * 流程
     */
    public void setProcess(java.lang.String process) {
        this.process = process;
    }
    /**
     * 合同约定申付起止时间
     */
    public java.util.Date getContractStartEndTime() {
        return contractStartEndTime;
    }

    /**
     * 合同约定申付起止时间
     */
    public void setContractStartEndTime(java.util.Date contractStartEndTime) {
        this.contractStartEndTime = contractStartEndTime;
    }

    public String getPaymentStartEndTime() {
        return paymentStartEndTime;
    }

    public void setPaymentStartEndTime(String paymentStartEndTime) {
        this.paymentStartEndTime = paymentStartEndTime;
    }

    /**
     * 策划申付起止时间
     */
    public java.util.Date getPlanStartEndTime() {
        return planStartEndTime;
    }

    /**
     * 策划申付起止时间
     */
    public void setPlanStartEndTime(java.util.Date planStartEndTime) {
        this.planStartEndTime = planStartEndTime;
    }
    /**
     * 审核人员
     */
    public java.lang.String getReviewers() {
        return reviewers;
    }

    /**
     * 审核人员
     */
    public void setReviewers(java.lang.String reviewers) {
        this.reviewers = reviewers;
    }
    /**
     * 项目部跟踪、对接责任人员
     */
    public java.lang.String getDocking() {
        return docking;
    }

    /**
     * 项目部跟踪、对接责任人员
     */
    public void setDocking(java.lang.String docking) {
        this.docking = docking;
    }
    /**
     * 应对措施
     */
    public java.lang.String getResponse() {
        return response;
    }

    /**
     * 应对措施
     */
    public void setResponse(java.lang.String response) {
        this.response = response;
    }
    
}
